==> cutemaze-1.2.1-1-src.tar.xz: cutemaze-1.2.1/translations/cutemaze_zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>抱歉</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>无法加载上次的游戏。将重新开始新游戏。</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>已消耗 %1 </translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>已消耗 %1 步</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>还剩 %2 个目标中的 %1 个</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>恭喜你，你赢了！</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>已暂停</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Command</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Option</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>选择本游戏的语言</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;系统语言&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>提示</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>请重启本程序使语言设置生效</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>新游戏</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Hunt and Kill 算法</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>克鲁斯克尔演算法</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>普里姆算法</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>递归回溯算法</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>栈</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>栈 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>栈 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>栈 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>栈 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>算法：</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>目标：</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Hunt and Kill 算法</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>克鲁斯克尔演算法</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>普里姆算法</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>递归回溯算法</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>栈</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>栈 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>栈 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>栈 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>栈 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>CuteMaze 分数</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>姓名</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>成绩</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>时间</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>步数</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>算法</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>恭喜！</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>您的成绩进入前十。
请输入尊姓大名：</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>游戏</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>显示已走过的路径</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>显示已走过的步数</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>显示已花费的时间</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>平稳运动</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>控制</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>上移</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>下移</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>左移</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>右移</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>留下标记</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>主题</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>选择主题文件</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>抱歉</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>无法创建数据文件夹</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>无法复制主题文件</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>问题</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>移除选定的主题？</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>无法移除选定的主题</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation>显示提示</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>关于 &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;游戏</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;新游戏</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;暂停</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;提示</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation> &amp;最高分</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;退出</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>放 &amp;大</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>缩 &amp;小</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;设置</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>程序 &amp;语言...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;偏好...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;帮助</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;关于</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>一个空中视角的迷宫游戏</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>版权所有 &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>基于 &lt;a href=%1&gt;GPL 3&lt;/a&gt; 协议发布</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>使用 &lt;a href=%1&gt;Oxygen&lt;/a&gt; 风格图标</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>在 &lt;a href=%1&gt;LGPL 3&lt;/a&gt; 协议下授权用户使用</translation>
    </message>
</context>
</TS>

==> cutemaze-1.2.6-1-src.tar.xz: cutemaze-1.2.6/translations/cutemaze_zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>抱歉</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>无法加载上次的游戏。将重新开始新游戏。</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>已用时 %1 </translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>已走 %1 步</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>还剩 %2 个目标中的 %1 个</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>恭喜你，你赢了！</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>已暂停</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Command</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Option</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>选择本游戏的语言:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;系统语言&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>提示</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>请重启本程序使语言设置生效。</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>新游戏</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Hunt and Kill 算法</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>克鲁斯克尔演算法</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>普里姆算法</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>递归回溯算法</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>栈</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>栈 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>栈 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>栈 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>栈 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>算法：</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>目标：</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Hunt and Kill 算法</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>克鲁斯克尔演算法</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>普里姆算法</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>递归回溯算法</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>栈</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>栈 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>栈 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>栈 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>栈 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>CuteMaze 分数榜</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>姓名</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>分数</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>时间</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>步数</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>算法</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>恭喜！</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>您的分数已进入前十。
请输入尊姓大名：</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>游戏</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>显示已走过的路径</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>显示已走过的步数</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>显示已花费的时间</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>平稳运动</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>控制</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>上移</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>下移</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>左移</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>右移</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>留下标记</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>主题</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>选择主题文件</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>抱歉</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>无法创建数据文件夹</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>无法复制主题文件</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>问题</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>移除选定的主题？</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>无法移除选定的主题</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation>显示提示</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>关于 &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;游戏</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;新游戏</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;暂停</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;提示</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation> &amp;高分榜</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;退出</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>放 &amp;大</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>缩 &amp;小</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;设置</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>程序 &amp;语言...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;偏好...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;帮助</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;关于</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>一个俯视视角的迷宫游戏</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>版权所有 &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>基于 &lt;a href=%1&gt;GPL 3&lt;/a&gt; 协议发布</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>使用 &lt;a href=%1&gt;Oxygen&lt;/a&gt; 风格图标</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>在 &lt;a href=%1&gt;LGPL 3&lt;/a&gt; 协议下授权用户使用</translation>
    </message>
</context>
</TS>
